## 0/20 Packaging conventions

### [x] 0/10 points: Provide a valid pubspec.yaml

<details>
<summary>
Homepage URL is insecure.
</summary>
Update the `homepage` field and use a secure (`https`) URL.
</details>
* `pubspec.yaml` doesn't have a `repository` entry.
<details>
<summary>
Documentation URL is insecure.
</summary>
Update the `documentation` field and use a secure (`https`) URL.
</details>
* `pubspec.yaml` doesn't have a `issue_tracker` entry.

### [x] 0/5 points: Provide a valid README.md

<details>
<summary>
Links in README.md should be secure. 9 links are insecure.
</summary>
`README.md:2:4`

```
  ╷
2 │ <p><a href="http://rikulo.org/projects/stream">Stream</a> is a Dart web server supporting request routing, filtering, template engine, WebSocket, MVC design pattern and file-based static resources.</p>
  │    ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  ╵
```

Use `https` URLs instead.
</details>

### [x] 0/5 points: Provide a valid CHANGELOG.md

<details>
<summary>
No CHANGELOG.md found.
</summary>
Changelog entries help developers follow the progress of your package. See the [example](https://raw.githubusercontent.com/dart-lang/stagehand/master/templates/package-simple/CHANGELOG.md) generated by `stagehand`.
</details>

## 0/10 Package has documentation

### [x] 0/10 points: Package has an example

<details>
<summary>
No example found.
</summary>
See [package layout](https://dart.dev/tools/pub/package-layout#examples) guidelines on how to add an example.
</details>

## 10/20 Package is multi-platform

### [~] 10/20 points: Supports 1 of 2 possible platforms (native, js)


## 0/20 Code follows recommended code style

### [x] 0/20 points: code has no errors, warnings, lints, or formatting issues

Found 1229 issues. Showing the first 2:

<details>
<summary>
ERROR: '_ReadOnlyHeaders.add' ('void Function(String, Object)') isn't a valid override of 'HttpHeaders.add' ('void Function(String, Object, {bool preserveHeaderCase})').
</summary>
`lib/src/connect_impl.dart:281:8`

```
    ╷
281 │   void add(String name, Object value) {
    │        ^^^
    ╵
```

To reproduce run `dart analyze lib/src/connect_impl.dart`
</details>
<details>
<summary>
ERROR: '_ReadOnlyHeaders.add' ('void Function(String, Object)') isn't a valid override of 'HttpHeadersWrapper.add' ('void Function(String, Object, {bool preserveHeaderCase})').
</summary>
`lib/src/connect_impl.dart:281:8`

```
    ╷
281 │   void add(String name, Object value) {
    │        ^^^
    ╵
```

To reproduce run `dart analyze lib/src/connect_impl.dart`
</details>

## 10/30 Package is a good, trustworthy dependency

### [*] 10/10 points: All of the package dependencies are supported in the latest version


### [x] 0/10 points: Package supports latest stable Dart and Flutter SDKs

* Found no Flutter in your PATH. Could not determine the current Flutter version.

### [x] 0/10 points: Package is published using a verified publisher

<details>
<summary>
Package is not published under a verified publisher.
</summary>
See https://dart.dev/tools/pub/verified-publishers for more information.
</details>